@@ -122,6 +122,9 @@ if is_open_saas_v2():  # V2
     BK_LOGIN_URL = BK_PAAS_HOST + "/login"
     BK_LOGIN_INNER_URL = BK_PAAS_INNER_HOST + "/login"
 
+    # V2环境 无该环境变量
+    BK_COMPONENT_API_URL = None
+
 else:  # V3
     # 蓝鲸PASS平台URL
     BK_PAAS_HOST = os.getenv("BK_PAAS2_URL", BK_URL).rstrip("/")
@@ -137,6 +140,9 @@ else:  # V3
     BK_LOGIN_URL = os.getenv("BK_LOGIN_URL", "%s/login" % BK_PAAS_HOST).rstrip("/")
     BK_LOGIN_INNER_URL = os.getenv("BK_LOGIN_INNER_URL", "%s/login" % BK_PAAS_INNER_HOST).rstrip("/")
 
+    # 容器化V3 ESB地址
+    BK_COMPONENT_API_URL = os.getenv("BK_COMPONENT_API_URL")
+
 
 # REMOTE_STATIC_URL
 REMOTE_STATIC_URL = "%sremote/" % STATIC_URL
